@@ -4,7 +4,7 @@
 #
 #     This program is under GPL [http://www.gnu.org/copyleft/gpl.htm]
 #
-#     (c) 2000,2001,2002,2003,2004 - Tom Eastep (teastep@shorewall.net)
+#     (c) 2000,2001,2002,2003,2004,2005 - Tom Eastep (teastep@shorewall.net)
 #
 #       Shorewall documentation is available at http://shorewall.net
 #
@@ -22,7 +22,7 @@
 #       Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 #
 
-VERSION=3.0.7
+VERSION=3.2.6
 
 usage() # $1 = exit status
 {
@@ -30,6 +30,7 @@ usage() # $1 = exit status
     echo "usage: $ME"
     echo "       $ME -v"
     echo "       $ME -h"
+    echo "       $ME -n"
     exit $1
 }
 
@@ -88,7 +89,7 @@ backup_directory() # $1 = directory to backup
 
 backup_file() # $1 = file to backup, $2 = (optional) Directory in which to create the backup
 {
-    if [ -z "$PREFIX" ]; then
+    if [ -z "${PREFIX}{NOBACKUP}" ]; then
 	if [ -f $1 -a ! -f ${1}-${VERSION}.bkout ]; then
 	    if [ -n "$2" ]; then
 		if [ -d $2 ]; then
@@ -155,6 +156,8 @@ if [ -z "$GROUP" ] ; then
 	GROUP=root
 fi
 
+NOBACKUP=
+
 while [ $# -gt 0 ] ; do
     case "$1" in
 	-h|help|?)
@@ -164,6 +167,9 @@ while [ $# -gt 0 ] ; do
 	    echo "Shorewall Firewall Installer Version $VERSION"
 	    exit 0
 	    ;;
+	-n)
+	    NOBACKUP=Yes
+	    ;;
 	*)
 	    usage 1
 	    ;;
@@ -181,15 +187,7 @@ DEBIAN=
 
 OWNERSHIP="-o $OWNER -g $GROUP"
 
-if [ -n "$PREFIX" ]; then
-	if [ `id -u` != 0 ] ; then
-	    echo "Not setting file owner/group permissions, not running as root."
-	    OWNERSHIP=""
-	fi
-
-	install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
-	install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
-elif [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
+if [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
     DEBIAN=yes
 elif [ -f /etc/slackware-version ] ; then
     DEST="/etc/rc.d"
@@ -199,6 +197,15 @@ elif [ -f /etc/arch-release ] ; then
       INIT="shorewall"
       ARCHLINUX=yes
 fi
+if [ -n "$PREFIX" ]; then
+	if [ `id -u` != 0 ] ; then
+	    echo "Not setting file owner/group permissions, not running as root."
+	    OWNERSHIP=""
+	fi
+
+	install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
+	install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
+fi
 
 #
 # Change to the directory containing this script
@@ -216,14 +223,16 @@ echo "Installing Shorewall Version $VERSION"
 #
 if [ -d ${PREFIX}/etc/shorewall ]; then
     first_install=""
-    backup_directory ${PREFIX}/etc/shorewall
-    backup_directory ${PREFIX}/usr/share/shorewall
-    backup_directory ${PREFIX}/var/lib/shorewall
+    if [ -z "$NOBACKUP" ]; then
+	backup_directory ${PREFIX}/etc/shorewall
+	backup_directory ${PREFIX}/usr/share/shorewall
+	backup_directory ${PREFIX}/var/lib/shorewall
+    fi
 else
     first_install="Yes"
 fi
 
-install_file_with_backup shorewall ${PREFIX}/sbin/shorewall 0544 ${PREFIX}/var/lib/shorewall-${VERSION}.bkout
+install_file_with_backup shorewall ${PREFIX}/sbin/shorewall 0555 ${PREFIX}/var/lib/shorewall-${VERSION}.bkout
 
 echo "shorewall control program installed in ${PREFIX}/sbin/shorewall"
 
@@ -246,21 +255,34 @@ echo  "Shorewall script installed in ${PREFIX}${DEST}/$INIT"
 #
 mkdir -p ${PREFIX}/etc/shorewall
 mkdir -p ${PREFIX}/usr/share/shorewall
+mkdir -p ${PREFIX}/usr/share/shorewall/configfiles
 mkdir -p ${PREFIX}/var/lib/shorewall
+
+chmod 755 ${PREFIX}/etc/shorewall
+chmod 755 ${PREFIX}/usr/share/shorewall
+chmod 755 ${PREFIX}/usr/share/shorewall/configfiles
+
 #
 # Install the config file
 #
+run_install $OWNERSHIP -m 0644 shorewall.conf ${PREFIX}/usr/share/shorewall/configfiles/shorewall.conf
+
+qt mywhich perl && perl -p -w -i -e 's|^CONFIG_PATH=.*|CONFIG_PATH=/usr/share/shorewall/configfiles:/usr/share/shorewall|;' ${PREFIX}/usr/share/shorewall/configfiles/shorewall.conf
+
 if [ ! -f ${PREFIX}/etc/shorewall/shorewall.conf ]; then
-   run_install $OWNERSHIP -m 0744 shorewall.conf ${PREFIX}/etc/shorewall/shorewall.conf
+   run_install $OWNERSHIP -m 0644 shorewall.conf ${PREFIX}/etc/shorewall/shorewall.conf
    echo "Config file installed as ${PREFIX}/etc/shorewall/shorewall.conf"
 fi
 
+
 if [ -n "$ARCHLINUX" ] ; then
    sed -e 's!LOGFILE=/var/log/messages!LOGFILE=/var/log/messages.log!' -i ${PREFIX}/etc/shorewall/shorewall.conf
 fi
 #
 # Install the zones file
 #
+run_install $OWNERSHIP -m 0644 zones ${PREFIX}/usr/share/shorewall/configfiles/zones
+
 if [ ! -f ${PREFIX}/etc/shorewall/zones ]; then
     run_install $OWNERSHIP -m 0744 zones ${PREFIX}/etc/shorewall/zones
     echo "Zones file installed as ${PREFIX}/etc/shorewall/zones"
@@ -275,15 +297,25 @@ install_file functions ${PREFIX}/usr/share/shorewall/functions 0444
 echo "Common functions installed in ${PREFIX}/usr/share/shorewall/functions"
 
 #
+# Install the Compiler
+#
+
+install_file compiler ${PREFIX}/usr/share/shorewall/compiler 0555
+
+echo
+echo "Compiler installed in ${PREFIX}/usr/share/shorewall/compiler"
+
 # Install the Help file
 #
-install_file help ${PREFIX}/usr/share/shorewall/help 0544
+install_file help ${PREFIX}/usr/share/shorewall/help 0555
 
 echo "Help command executor installed in ${PREFIX}/usr/share/shorewall/help"
 
 #
 # Install the policy file
 #
+run_install $OWNERSHIP -m 0644 policy ${PREFIX}/usr/share/shorewall/configfiles/policy
+
 if [ ! -f ${PREFIX}/etc/shorewall/policy ]; then
     run_install $OWNERSHIP -m 0600 policy ${PREFIX}/etc/shorewall/policy
     echo "Policy file installed as ${PREFIX}/etc/shorewall/policy"
@@ -291,6 +323,8 @@ fi
 #
 # Install the interfaces file
 #
+run_install $OWNERSHIP -m 0644 interfaces ${PREFIX}/usr/share/shorewall/configfiles/interfaces
+
 if [ ! -f ${PREFIX}/etc/shorewall/interfaces ]; then
     run_install $OWNERSHIP -m 0600 interfaces ${PREFIX}/etc/shorewall/interfaces
     echo "Interfaces file installed as ${PREFIX}/etc/shorewall/interfaces"
@@ -298,6 +332,8 @@ fi
 #
 # Install the ipsec file
 #
+run_install $OWNERSHIP -m 0644 ipsec ${PREFIX}/usr/share/shorewall/configfiles/ipsec
+
 if [ ! -f ${PREFIX}/etc/shorewall/ipsec ]; then
     run_install $OWNERSHIP -m 0600 ipsec ${PREFIX}/etc/shorewall/ipsec
     echo "Dummy IPSEC file installed as ${PREFIX}/etc/shorewall/ipsec"
@@ -306,6 +342,8 @@ fi
 #
 # Install the hosts file
 #
+run_install $OWNERSHIP -m 0644 hosts ${PREFIX}/usr/share/shorewall/configfiles/hosts
+
 if [ ! -f ${PREFIX}/etc/shorewall/hosts ]; then
     run_install $OWNERSHIP -m 0600 hosts ${PREFIX}/etc/shorewall/hosts
     echo "Hosts file installed as ${PREFIX}/etc/shorewall/hosts"
@@ -313,6 +351,8 @@ fi
 #
 # Install the rules file
 #
+run_install $OWNERSHIP -m 0644 rules ${PREFIX}/usr/share/shorewall/configfiles/rules
+
 if [ ! -f ${PREFIX}/etc/shorewall/rules ]; then
     run_install $OWNERSHIP -m 0600 rules ${PREFIX}/etc/shorewall/rules
     echo "Rules file installed as ${PREFIX}/etc/shorewall/rules"
@@ -320,6 +360,8 @@ fi
 #
 # Install the NAT file
 #
+run_install $OWNERSHIP -m 0644 nat ${PREFIX}/usr/share/shorewall/configfiles/nat
+
 if [ ! -f ${PREFIX}/etc/shorewall/nat ]; then
     run_install $OWNERSHIP -m 0600 nat ${PREFIX}/etc/shorewall/nat
     echo "NAT file installed as ${PREFIX}/etc/shorewall/nat"
@@ -327,6 +369,8 @@ fi
 #
 # Install the NETMAP file
 #
+run_install $OWNERSHIP -m 0644 netmap ${PREFIX}/usr/share/shorewall/configfiles/netmap
+
 if [ ! -f ${PREFIX}/etc/shorewall/netmap ]; then
     run_install $OWNERSHIP -m 0600 netmap ${PREFIX}/etc/shorewall/netmap
     echo "NETMAP file installed as ${PREFIX}/etc/shorewall/netmap"
@@ -334,13 +378,17 @@ fi
 #
 # Install the Parameters file
 #
+run_install $OWNERSHIP -m 0644 params ${PREFIX}/usr/share/shorewall/configfiles/params
+
 if [ ! -f ${PREFIX}/etc/shorewall/params ]; then
-    run_install $OWNERSHIP -m 0600 params ${PREFIX}/etc/shorewall/params
+    run_install $OWNERSHIP -m 0644 params ${PREFIX}/etc/shorewall/params
     echo "Parameter file installed as ${PREFIX}/etc/shorewall/params"
 fi
 #
 # Install the proxy ARP file
 #
+run_install $OWNERSHIP -m 0644 proxyarp ${PREFIX}/usr/share/shorewall/configfiles/proxyarp
+
 if [ ! -f ${PREFIX}/etc/shorewall/proxyarp ]; then
     run_install $OWNERSHIP -m 0600 proxyarp ${PREFIX}/etc/shorewall/proxyarp
     echo "Proxy ARP file installed as ${PREFIX}/etc/shorewall/proxyarp"
@@ -348,6 +396,8 @@ fi
 #
 # Install the Stopped Routing file
 #
+run_install $OWNERSHIP -m 0644 routestopped ${PREFIX}/usr/share/shorewall/configfiles/routestopped
+
 if [ ! -f ${PREFIX}/etc/shorewall/routestopped ]; then
     run_install $OWNERSHIP -m 0600 routestopped ${PREFIX}/etc/shorewall/routestopped
     echo "Stopped Routing file installed as ${PREFIX}/etc/shorewall/routestopped"
@@ -355,6 +405,8 @@ fi
 #
 # Install the Mac List file
 #
+run_install $OWNERSHIP -m 0644 maclist ${PREFIX}/usr/share/shorewall/configfiles/maclist
+
 if [ ! -f ${PREFIX}/etc/shorewall/maclist ]; then
     run_install $OWNERSHIP -m 0600 maclist ${PREFIX}/etc/shorewall/maclist
     echo "MAC list file installed as ${PREFIX}/etc/shorewall/maclist"
@@ -362,6 +414,8 @@ fi
 #
 # Install the Masq file
 #
+run_install $OWNERSHIP -m 0644 masq ${PREFIX}/usr/share/shorewall/configfiles/masq
+
 if [ ! -f ${PREFIX}/etc/shorewall/masq ]; then
     run_install $OWNERSHIP -m 0600 masq ${PREFIX}/etc/shorewall/masq
     echo "Masquerade file installed as ${PREFIX}/etc/shorewall/masq"
@@ -369,13 +423,14 @@ fi
 #
 # Install the Modules file
 #
-if [ ! -f ${PREFIX}/etc/shorewall/modules ]; then
-    run_install $OWNERSHIP -m 0600 modules ${PREFIX}/etc/shorewall/modules
-    echo "Modules file installed as ${PREFIX}/etc/shorewall/modules"
-fi
+run_install $OWNERSHIP -m 0600 modules ${PREFIX}/usr/share/shorewall/modules
+echo "Modules file installed as ${PREFIX}/usr/share/shorewall/modules"
+
 #
 # Install the TC Rules file
 #
+run_install $OWNERSHIP -m 0644 tcrules ${PREFIX}/usr/share/shorewall/configfiles/tcrules
+
 if [ ! -f ${PREFIX}/etc/shorewall/tcrules ]; then
     run_install $OWNERSHIP -m 0600 tcrules ${PREFIX}/etc/shorewall/tcrules
     echo "TC Rules file installed as ${PREFIX}/etc/shorewall/tcrules"
@@ -384,6 +439,8 @@ fi
 #
 # Install the TOS file
 #
+run_install $OWNERSHIP -m 0644 tos ${PREFIX}/usr/share/shorewall/configfiles/tos
+
 if [ ! -f ${PREFIX}/etc/shorewall/tos ]; then
     run_install $OWNERSHIP -m 0600 tos ${PREFIX}/etc/shorewall/tos
     echo "TOS file installed as ${PREFIX}/etc/shorewall/tos"
@@ -391,6 +448,8 @@ fi
 #
 # Install the Tunnels file
 #
+run_install $OWNERSHIP -m 0644 tunnels ${PREFIX}/usr/share/shorewall/configfiles/tunnels
+
 if [ ! -f ${PREFIX}/etc/shorewall/tunnels ]; then
     run_install $OWNERSHIP -m 0600 tunnels ${PREFIX}/etc/shorewall/tunnels
     echo "Tunnels file installed as ${PREFIX}/etc/shorewall/tunnels"
@@ -398,6 +457,8 @@ fi
 #
 # Install the blacklist file
 #
+run_install $OWNERSHIP -m 0644 blacklist ${PREFIX}/usr/share/shorewall/configfiles/blacklist
+
 if [ ! -f ${PREFIX}/etc/shorewall/blacklist ]; then
     run_install $OWNERSHIP -m 0600 blacklist ${PREFIX}/etc/shorewall/blacklist
     echo "Blacklist file installed as ${PREFIX}/etc/shorewall/blacklist"
@@ -412,17 +473,37 @@ delete_file ${PREFIX}/etc/shorewall/routes
 
 delete_file ${PREFIX}/usr/share/shorewall/tcstart
 
+#
+# Delete the xmodules file
+#
+
+delete_file ${PREFIX}/usr/share/shorewall/xmodules
+
 #
 # Install the Providers file
 #
+run_install $OWNERSHIP -m 0644 providers ${PREFIX}/usr/share/shorewall/configfiles/providers
+
 if [ ! -f ${PREFIX}/etc/shorewall/providers ]; then
     run_install $OWNERSHIP -m 0600 providers ${PREFIX}/etc/shorewall/providers
     echo "Providers file installed as ${PREFIX}/etc/shorewall/providers"
 fi
 
+#
+# Install the Route Rules file
+#
+run_install $OWNERSHIP -m 0644 route_rules ${PREFIX}/usr/share/shorewall/configfiles/route_rules
+
+if [ ! -f ${PREFIX}/etc/shorewall/route_rules ]; then
+    run_install $OWNERSHIP -m 0600 route_rules ${PREFIX}/etc/shorewall/route_rules
+    echo "Routing rules file installed as ${PREFIX}/etc/shorewall/route_rules"
+fi
+
 #
 # Install the tcclasses file
 #
+run_install $OWNERSHIP -m 0644 tcclasses ${PREFIX}/usr/share/shorewall/configfiles/tcclasses
+
 if [ ! -f ${PREFIX}/etc/shorewall/tcclasses ]; then
     run_install $OWNERSHIP -m 0600 tcclasses ${PREFIX}/etc/shorewall/tcclasses
     echo "TC Classes file installed as ${PREFIX}/etc/shorewall/tcclasses"
@@ -431,6 +512,8 @@ fi
 #
 # Install the tcdevices file
 #
+run_install $OWNERSHIP -m 0644 tcdevices ${PREFIX}/usr/share/shorewall/configfiles/tcdevices
+
 if [ ! -f ${PREFIX}/etc/shorewall/tcdevices ]; then
     run_install $OWNERSHIP -m 0600 tcdevices ${PREFIX}/etc/shorewall/tcdevices
     echo "TC Devices file installed as ${PREFIX}/etc/shorewall/tcdevices"
@@ -439,16 +522,18 @@ fi
 #
 # Install the rfc1918 file
 #
-install_file rfc1918 ${PREFIX}/usr/share/shorewall/rfc1918 0600
+install_file rfc1918 ${PREFIX}/usr/share/shorewall/rfc1918 0644
 echo "RFC 1918 file installed as ${PREFIX}/usr/share/shorewall/rfc1918"
 #
 # Install the default config path file
 #
-install_file configpath ${PREFIX}/usr/share/shorewall/configpath 0600
+install_file configpath ${PREFIX}/usr/share/shorewall/configpath 0644
 echo "Default config path file installed as ${PREFIX}/usr/share/shorewall/configpath"
 #
 # Install the init file
 #
+run_install $OWNERSHIP -m 0644 init ${PREFIX}/usr/share/shorewall/configfiles/init
+
 if [ ! -f ${PREFIX}/etc/shorewall/init ]; then
     run_install $OWNERSHIP -m 0600 init ${PREFIX}/etc/shorewall/init
     echo "Init file installed as ${PREFIX}/etc/shorewall/init"
@@ -456,6 +541,8 @@ fi
 #
 # Install the initdone file
 #
+run_install $OWNERSHIP -m 0644 initdone ${PREFIX}/usr/share/shorewall/configfiles/initdone
+
 if [ ! -f ${PREFIX}/etc/shorewall/initdone ]; then
     run_install $OWNERSHIP -m 0600 initdone ${PREFIX}/etc/shorewall/initdone
     echo "Initdone file installed as ${PREFIX}/etc/shorewall/initdone"
@@ -463,6 +550,8 @@ fi
 #
 # Install the start file
 #
+run_install $OWNERSHIP -m 0644 start ${PREFIX}/usr/share/shorewall/configfiles/start
+
 if [ ! -f ${PREFIX}/etc/shorewall/start ]; then
     run_install $OWNERSHIP -m 0600 start ${PREFIX}/etc/shorewall/start
     echo "Start file installed as ${PREFIX}/etc/shorewall/start"
@@ -470,6 +559,8 @@ fi
 #
 # Install the stop file
 #
+run_install $OWNERSHIP -m 0644 stop ${PREFIX}/usr/share/shorewall/configfiles/stop
+
 if [ ! -f ${PREFIX}/etc/shorewall/stop ]; then
     run_install $OWNERSHIP -m 0600 stop ${PREFIX}/etc/shorewall/stop
     echo "Stop file installed as ${PREFIX}/etc/shorewall/stop"
@@ -477,6 +568,8 @@ fi
 #
 # Install the stopped file
 #
+run_install $OWNERSHIP -m 0644 stopped ${PREFIX}/usr/share/shorewall/configfiles/stopped
+
 if [ ! -f ${PREFIX}/etc/shorewall/stopped ]; then
     run_install $OWNERSHIP -m 0600 stopped ${PREFIX}/etc/shorewall/stopped
     echo "Stopped file installed as ${PREFIX}/etc/shorewall/stopped"
@@ -484,6 +577,8 @@ fi
 #
 # Install the ECN file
 #
+run_install $OWNERSHIP -m 0644 ecn ${PREFIX}/usr/share/shorewall/configfiles/ecn
+
 if [ ! -f ${PREFIX}/etc/shorewall/ecn ]; then
     run_install $OWNERSHIP -m 0600 ecn ${PREFIX}/etc/shorewall/ecn
     echo "ECN file installed as ${PREFIX}/etc/shorewall/ecn"
@@ -491,6 +586,8 @@ fi
 #
 # Install the Accounting file
 #
+run_install $OWNERSHIP -m 0644 accounting ${PREFIX}/usr/share/shorewall/configfiles/accounting
+
 if [ ! -f ${PREFIX}/etc/shorewall/accounting ]; then
     run_install $OWNERSHIP -m 0600 accounting ${PREFIX}/etc/shorewall/accounting
     echo "Accounting file installed as ${PREFIX}/etc/shorewall/accounting"
@@ -498,6 +595,8 @@ fi
 #
 # Install the Continue file
 #
+run_install $OWNERSHIP -m 0644 continue ${PREFIX}/usr/share/shorewall/configfiles/continue
+
 if [ ! -f ${PREFIX}/etc/shorewall/continue ]; then
     run_install $OWNERSHIP -m 0600 continue ${PREFIX}/etc/shorewall/continue
     echo "Continue file installed as ${PREFIX}/etc/shorewall/continue"
@@ -505,6 +604,8 @@ fi
 #
 # Install the Started file
 #
+run_install $OWNERSHIP -m 0644 started ${PREFIX}/usr/share/shorewall/configfiles/started
+
 if [ ! -f ${PREFIX}/etc/shorewall/started ]; then
     run_install $OWNERSHIP -m 0600 started ${PREFIX}/etc/shorewall/started
     echo "Started file installed as ${PREFIX}/etc/shorewall/started"
@@ -512,20 +613,23 @@ fi
 #
 # Install the Standard Actions file
 #
-install_file actions.std ${PREFIX}/usr/share/shorewall/actions.std 0600
+install_file actions.std ${PREFIX}/usr/share/shorewall/actions.std 0644
 echo "Standard actions file installed as ${PREFIX}/etc/shorewall/actions.std"
 
 #
 # Install the Actions file
 #
+run_install $OWNERSHIP -m 0644 actions ${PREFIX}/usr/share/shorewall/configfiles/actions
+
 if [ ! -f ${PREFIX}/etc/shorewall/actions ]; then
-    run_install $OWNERSHIP -m 0600 actions ${PREFIX}/etc/shorewall/actions
+    run_install $OWNERSHIP -m 0644 actions ${PREFIX}/etc/shorewall/actions
     echo "Actions file installed as ${PREFIX}/etc/shorewall/actions"
 fi
 
 #
 # Install the  Makefile
 #
+run_install $OWNERSHIP -m 0644 Makefile ${PREFIX}/usr/share/shorewall/configfiles/Makefile
 run_install $OWNERSHIP -m 0600 Makefile ${PREFIX}/etc/shorewall/Makefile
 echo "Makefile installed as ${PREFIX}/etc/shorewall/Makefile"
 
@@ -533,20 +637,26 @@ echo "Makefile installed as ${PREFIX}/etc/shorewall/Makefile"
 # Install the Action files
 #
 for f in action.* ; do
-    install_file $f ${PREFIX}/usr/share/shorewall/$f 0600
+    install_file $f ${PREFIX}/usr/share/shorewall/$f 0644
     echo "Action ${f#*.} file installed as ${PREFIX}/usr/share/shorewall/$f"
 done
 
-install_file Limit ${PREFIX}/usr/share/shorewall/Limit 0600
+install_file Limit ${PREFIX}/usr/share/shorewall/Limit 0644
 echo "Limit action extension script installed as ${PREFIX}/usr/share/shorewall/Limit"
 #
 # Install the Macro files
 #
 for f in macro.* ; do
-    install_file $f ${PREFIX}/usr/share/shorewall/$f 0600
+    install_file $f ${PREFIX}/usr/share/shorewall/$f 0644
     echo "Macro ${f#*.} file installed as ${PREFIX}/usr/share/shorewall/$f"
 done
-
+#
+# Install the program skeleton files
+#
+for f in prog.* ; do
+    install_file $f ${PREFIX}/usr/share/shorewall/$f 0644
+    echo "Program skeleton file ${f#*.} installed as ${PREFIX}/usr/share/shorewall/$f"
+done
 #
 # Create the version file
 #
@@ -564,7 +674,7 @@ fi
 #
 # Install the firewall script
 #
-install_file firewall ${PREFIX}/usr/share/shorewall/firewall 0544
+install_file firewall ${PREFIX}/usr/share/shorewall/firewall 0555
 
 if [ -z "$PREFIX" -a -n "$first_install" ]; then
     if [ -n "$DEBIAN" ]; then
